<?php

/**
 * This is RSS 2.0 parsing callback function
 */
function _aggregation_RSS20_parse($feed_XML, $feed)
{
	foreach ($feed_XML->xpath('//item') AS $news)
	{
		// for PHP > 5.1.2 get 'content' namespace
		$content = $news->children('http://purl.org/rss/1.0/modules/content/');
		$dc = $news->children('http://purl.org/dc/elements/1.1/');

		if ($news->guid)
			$guid = "{$news->guid}";
		else
			$guid = NULL;

		if ($news->title)
			$title = "{$news->title}";
		else
			$title = '';

		$body = '';
		if ($news->description)
		{
		  foreach($news->description->children() as $child) 
		    $body .= $child->asXML();
		  $body .= "{$news->description}";
		}
		// some sources use content:encoded as description i.e. PostNuke PageSetter module
		elseif ($news->encoded)  //content:encoded for PHP < 5.1.2
		{
		  foreach($news->encoded->children() as $child) 
		    $body .= $child->asXML();
		  $body .= "{$news->encoded}";
		}
		elseif ($content->encoded)  //content:encoded for PHP >= 5.1.2
		{
		  foreach($content->encoded->children() as $child) 
		    $body .= $child->asXML();
		  $body .= "{$content->encoded}";
		}
		else
			$body = $title;

		$teaser = node_teaser($body);
		
		if ($news->author)
			$original_author = "{$news->author}";
		elseif ($dc->creator)
		  	$original_author = "{$dc->creator}";
		elseif ($feed_XML->channel->title)
			$original_author = "{$feed_XML->channel->title}";
		else
			$original_author = $feed->original_author;
		
		if ($news->link)
			$original_url = "{$news->link}";
		else
			$original_url = NULL;

		$timestamp = strtotime("{$news->pubDate}");
		if ($timestamp === FALSE)
			$timestamp = time();

		$additional_taxonomies = array();
		
		if ($news->category)
		{
			$additional_taxonomies['Content'] = array();
			$additional_taxonomies['Tags'] = array();
			$contentcatlist = array("Photos", "Videos", "Journal", "About", "Musings", "Quote");
			
			foreach ($news->category AS $cat) 
			{
			      	$subcats = explode('.', $cat);
			      	$main = array_shift($subcats);
			      	if ($main == "Quote of the Week") $main = "Quote";
			      	if (in_array($main, $contentcatlist)) array_push($additional_taxonomies['Content'], $main);
			      	else array_push($additional_taxonomies['Tags'], $main);
			      	$additional_taxonomies['Tags'] = array_merge($additional_taxonomies['Tags'], $subcats);
			}
			$additional_taxonomies['Content'] = array_unique($additional_taxonomies['Content']);
			$additional_taxonomies['Tags'] = array_unique($additional_taxonomies['Tags']);
		}

  	$other = array();	
    
  	if ($news['comments']) 
  		$other['original_comments'] = $news['comments'];
  	
  	_aggregation_add_item($title, $body, $teaser, $original_author, $feed, $additional_taxonomies, $timestamp, $original_url, $guid, array(), $other);
	}
}
